nbxmpp.bosh

Package nbxmpp :: Module bosh |
[hide private]
[frames] | no frames]

# Module bosh

source code

Classes | [hide private]
| NonBlockingBOSH
| AckChecker Class for generating rids and generating and checking acknowledgements in BOSH messages
| KeyStack Class implementing key sequences for BOSH messages

Functions | [hide private]
get_rand_number() | source code

Variables | [hide private]
| log = `logging.getLogger('nbxmpp.bosh')`
| KEY_COUNT = `10`
| FAKE_DESCRIPTOR = `-1337`
| bosh_errors = ``{``'``bad-request``'``:` `'``The format of an HTTP header or``...``
| __package__ = ``'``nbxmpp``'``

Imports: locale, random, sha1, NonBlockingTransport, NonBlockingHTTPBOSH, CONNECTED, CONNECTING, DISCONNECTED, DISCONNECTING, urisplit, DISCONNECT_TIMEOUT_SECONDS, BOSHBody, Protocol, NS_CLIENT, Node, logging

Function Details | [hide private]

### get_rand_number() | source code

Variables Details | [hide private]

  ### log Value:
      logging.getLogger('nbxmpp.bosh')

  ### KEY_COUNT Value:
      10

  ### FAKE_DESCRIPTOR Value:
      -1337

  ### bosh_errors Value:
      {'bad-request': 'The format of an HTTP header or binding element recei
      ved from the client is unacceptable (e.g., syntax error), or Script Sy
      ntax is not supported.',
       'host-gone': 'The target domain specified in the "to" attribute or th
      e target host or port specified in the "route" attribute is no longer
      serviced by the connection manager.',
       'host-unknown': 'The target domain specified in the "to" attribute or
       the target host or port specified in the "route" attribute is unknown
      ...

  ### __package__ Value:
      'nbxmpp'